Class: Google::Cloud::GeminiDataAnalytics::V1::AnalysisMessage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb

Overview

A message produced during analysis.

Instance Attribute Summary collapse

Instance Attribute Details

#progress_event::Google::Cloud::GeminiDataAnalytics::V1::AnalysisEvent

Returns An event indicating the progress of the analysis.

Note: The following fields are mutually exclusive: progress_event, query. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::GeminiDataAnalytics::V1::AnalysisEvent)

    An event indicating the progress of the analysis.

    Note: The following fields are mutually exclusive: progress_event, query. If a field in that set is populated, all other fields in the set will automatically be cleared.



526
527
528
529
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 526

class AnalysisMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query::Google::Cloud::GeminiDataAnalytics::V1::AnalysisQuery

Returns An analysis query.

Note: The following fields are mutually exclusive: query, progress_event. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



526
527
528
529
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 526

class AnalysisMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end