Class: Google::Cloud::GeminiDataAnalytics::V1::BigQueryRoutine
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::BigQueryRoutine
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/context.rb
Overview
A reference to a BigQuery routine.
Instance Attribute Summary collapse
-
#description ⇒ ::String
User override or addition to description, to tell the agent when to use the UDF.
-
#routine_reference ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::BigQueryRoutineReference
The reference to the BigQuery routine.
Instance Attribute Details
#description ⇒ ::String
Returns User override or addition to description, to tell the agent when to use the UDF.
139 140 141 142 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 139 class BigQueryRoutine include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#routine_reference ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::BigQueryRoutineReference
Returns The reference to the BigQuery routine.
139 140 141 142 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 139 class BigQueryRoutine include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |