Class: Google::Cloud::GeminiDataAnalytics::V1::Context

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/context.rb

Overview

A collection of context to apply to this conversation

Defined Under Namespace

Classes: SchemaRelationship

Instance Attribute Summary collapse

Instance Attribute Details

#datasource_references::Google::Cloud::GeminiDataAnalytics::V1::DatasourceReferences

Returns Required. Data sources that are available for answering the question.

Returns:



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 61

class Context
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The relationship between two tables, including referencing and referenced
  # columns. This is a derived context retrieved from Dataplex Dataset
  # Insights.
  # @!attribute [rw] left_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the first table.
  #     The size of this list must be the same as `right_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `right_schema_paths` list.
  # @!attribute [rw] right_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the second table.
  #     The size of this list must be the same as `left_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `left_schema_paths` list.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::Source>]
  #     Optional. Sources which generated the schema relation edge.
  # @!attribute [rw] confidence_score
  #   @return [::Float]
  #     Optional. A confidence score for the suggested relationship.
  #     Manually added edges have the highest confidence score.
  class SchemaRelationship
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents an ordered set of paths within the table schema.
    # @!attribute [rw] table_fqn
    #   @return [::String]
    #     The service-qualified full resource name of the table
    #     Ex:
    #     bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
    # @!attribute [rw] paths
    #   @return [::Array<::String>]
    #     The ordered list of paths within the table schema.
    class SchemaPaths
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Source which generated the schema relation edge.
    module Source
      # The source of the schema relationship is unspecified.
      SOURCE_UNSPECIFIED = 0

      # The source of the schema relationship is BigQuery job history.
      BIGQUERY_JOB_HISTORY = 1

      # The source of the schema relationship is LLM suggested.
      LLM_SUGGESTED = 2

      # The source of the schema relationship is BigQuery table constraints.
      BIGQUERY_TABLE_CONSTRAINTS = 3
    end
  end
end

#example_queries::Array<::Google::Cloud::GeminiDataAnalytics::V1::ExampleQuery>

Returns Optional. A list of example queries, providing examples of relevant and commonly used SQL queries and their corresponding natural language queries optionally present. Currently only used for BigQuery data sources and databases (alloydb, cloudsql, spanner) data sources.

Returns:

  • (::Array<::Google::Cloud::GeminiDataAnalytics::V1::ExampleQuery>)

    Optional. A list of example queries, providing examples of relevant and commonly used SQL queries and their corresponding natural language queries optionally present. Currently only used for BigQuery data sources and databases (alloydb, cloudsql, spanner) data sources.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 61

class Context
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The relationship between two tables, including referencing and referenced
  # columns. This is a derived context retrieved from Dataplex Dataset
  # Insights.
  # @!attribute [rw] left_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the first table.
  #     The size of this list must be the same as `right_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `right_schema_paths` list.
  # @!attribute [rw] right_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the second table.
  #     The size of this list must be the same as `left_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `left_schema_paths` list.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::Source>]
  #     Optional. Sources which generated the schema relation edge.
  # @!attribute [rw] confidence_score
  #   @return [::Float]
  #     Optional. A confidence score for the suggested relationship.
  #     Manually added edges have the highest confidence score.
  class SchemaRelationship
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents an ordered set of paths within the table schema.
    # @!attribute [rw] table_fqn
    #   @return [::String]
    #     The service-qualified full resource name of the table
    #     Ex:
    #     bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
    # @!attribute [rw] paths
    #   @return [::Array<::String>]
    #     The ordered list of paths within the table schema.
    class SchemaPaths
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Source which generated the schema relation edge.
    module Source
      # The source of the schema relationship is unspecified.
      SOURCE_UNSPECIFIED = 0

      # The source of the schema relationship is BigQuery job history.
      BIGQUERY_JOB_HISTORY = 1

      # The source of the schema relationship is LLM suggested.
      LLM_SUGGESTED = 2

      # The source of the schema relationship is BigQuery table constraints.
      BIGQUERY_TABLE_CONSTRAINTS = 3
    end
  end
end

#glossary_terms::Array<::Google::Cloud::GeminiDataAnalytics::V1::GlossaryTerm>

Returns Optional. Term definitions (currently, only user authored) Not supported for databases (alloydb, cloudsql, spanner) data sources.

Returns:



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 61

class Context
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The relationship between two tables, including referencing and referenced
  # columns. This is a derived context retrieved from Dataplex Dataset
  # Insights.
  # @!attribute [rw] left_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the first table.
  #     The size of this list must be the same as `right_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `right_schema_paths` list.
  # @!attribute [rw] right_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the second table.
  #     The size of this list must be the same as `left_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `left_schema_paths` list.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::Source>]
  #     Optional. Sources which generated the schema relation edge.
  # @!attribute [rw] confidence_score
  #   @return [::Float]
  #     Optional. A confidence score for the suggested relationship.
  #     Manually added edges have the highest confidence score.
  class SchemaRelationship
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents an ordered set of paths within the table schema.
    # @!attribute [rw] table_fqn
    #   @return [::String]
    #     The service-qualified full resource name of the table
    #     Ex:
    #     bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
    # @!attribute [rw] paths
    #   @return [::Array<::String>]
    #     The ordered list of paths within the table schema.
    class SchemaPaths
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Source which generated the schema relation edge.
    module Source
      # The source of the schema relationship is unspecified.
      SOURCE_UNSPECIFIED = 0

      # The source of the schema relationship is BigQuery job history.
      BIGQUERY_JOB_HISTORY = 1

      # The source of the schema relationship is LLM suggested.
      LLM_SUGGESTED = 2

      # The source of the schema relationship is BigQuery table constraints.
      BIGQUERY_TABLE_CONSTRAINTS = 3
    end
  end
end

#looker_golden_queries::Array<::Google::Cloud::GeminiDataAnalytics::V1::LookerGoldenQuery>

Returns Optional. A list of golden queries, providing examples of relevant and commonly used Looker queries and their corresponding natural language queries optionally present. Only supported for Looker data sources.

Returns:



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 61

class Context
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The relationship between two tables, including referencing and referenced
  # columns. This is a derived context retrieved from Dataplex Dataset
  # Insights.
  # @!attribute [rw] left_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the first table.
  #     The size of this list must be the same as `right_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `right_schema_paths` list.
  # @!attribute [rw] right_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the second table.
  #     The size of this list must be the same as `left_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `left_schema_paths` list.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::Source>]
  #     Optional. Sources which generated the schema relation edge.
  # @!attribute [rw] confidence_score
  #   @return [::Float]
  #     Optional. A confidence score for the suggested relationship.
  #     Manually added edges have the highest confidence score.
  class SchemaRelationship
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents an ordered set of paths within the table schema.
    # @!attribute [rw] table_fqn
    #   @return [::String]
    #     The service-qualified full resource name of the table
    #     Ex:
    #     bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
    # @!attribute [rw] paths
    #   @return [::Array<::String>]
    #     The ordered list of paths within the table schema.
    class SchemaPaths
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Source which generated the schema relation edge.
    module Source
      # The source of the schema relationship is unspecified.
      SOURCE_UNSPECIFIED = 0

      # The source of the schema relationship is BigQuery job history.
      BIGQUERY_JOB_HISTORY = 1

      # The source of the schema relationship is LLM suggested.
      LLM_SUGGESTED = 2

      # The source of the schema relationship is BigQuery table constraints.
      BIGQUERY_TABLE_CONSTRAINTS = 3
    end
  end
end

#options::Google::Cloud::GeminiDataAnalytics::V1::ConversationOptions

Returns Optional. Additional options for the conversation.

Returns:



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 61

class Context
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The relationship between two tables, including referencing and referenced
  # columns. This is a derived context retrieved from Dataplex Dataset
  # Insights.
  # @!attribute [rw] left_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the first table.
  #     The size of this list must be the same as `right_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `right_schema_paths` list.
  # @!attribute [rw] right_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the second table.
  #     The size of this list must be the same as `left_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `left_schema_paths` list.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::Source>]
  #     Optional. Sources which generated the schema relation edge.
  # @!attribute [rw] confidence_score
  #   @return [::Float]
  #     Optional. A confidence score for the suggested relationship.
  #     Manually added edges have the highest confidence score.
  class SchemaRelationship
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents an ordered set of paths within the table schema.
    # @!attribute [rw] table_fqn
    #   @return [::String]
    #     The service-qualified full resource name of the table
    #     Ex:
    #     bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
    # @!attribute [rw] paths
    #   @return [::Array<::String>]
    #     The ordered list of paths within the table schema.
    class SchemaPaths
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Source which generated the schema relation edge.
    module Source
      # The source of the schema relationship is unspecified.
      SOURCE_UNSPECIFIED = 0

      # The source of the schema relationship is BigQuery job history.
      BIGQUERY_JOB_HISTORY = 1

      # The source of the schema relationship is LLM suggested.
      LLM_SUGGESTED = 2

      # The source of the schema relationship is BigQuery table constraints.
      BIGQUERY_TABLE_CONSTRAINTS = 3
    end
  end
end

#schema_relationships::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship>

Returns Optional. Relationships between table schema, including referencing and referenced columns.

Returns:



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 61

class Context
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The relationship between two tables, including referencing and referenced
  # columns. This is a derived context retrieved from Dataplex Dataset
  # Insights.
  # @!attribute [rw] left_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the first table.
  #     The size of this list must be the same as `right_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `right_schema_paths` list.
  # @!attribute [rw] right_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the second table.
  #     The size of this list must be the same as `left_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `left_schema_paths` list.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::Source>]
  #     Optional. Sources which generated the schema relation edge.
  # @!attribute [rw] confidence_score
  #   @return [::Float]
  #     Optional. A confidence score for the suggested relationship.
  #     Manually added edges have the highest confidence score.
  class SchemaRelationship
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents an ordered set of paths within the table schema.
    # @!attribute [rw] table_fqn
    #   @return [::String]
    #     The service-qualified full resource name of the table
    #     Ex:
    #     bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
    # @!attribute [rw] paths
    #   @return [::Array<::String>]
    #     The ordered list of paths within the table schema.
    class SchemaPaths
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Source which generated the schema relation edge.
    module Source
      # The source of the schema relationship is unspecified.
      SOURCE_UNSPECIFIED = 0

      # The source of the schema relationship is BigQuery job history.
      BIGQUERY_JOB_HISTORY = 1

      # The source of the schema relationship is LLM suggested.
      LLM_SUGGESTED = 2

      # The source of the schema relationship is BigQuery table constraints.
      BIGQUERY_TABLE_CONSTRAINTS = 3
    end
  end
end

#system_instruction::String

Returns Optional. The basic entry point for data owners creating domain knowledge for Agent.

Why: Business jargon (e.g., YTD revenue is calculated as…, Retirement Age is 65 in the USA, etc) and system instructions (e.g., answer like a Pirate) can help the model understand the business context around a user question.

Returns:

  • (::String)

    Optional. The basic entry point for data owners creating domain knowledge for Agent.

    Why: Business jargon (e.g., YTD revenue is calculated as…, Retirement Age is 65 in the USA, etc) and system instructions (e.g., answer like a Pirate) can help the model understand the business context around a user question.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 61

class Context
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The relationship between two tables, including referencing and referenced
  # columns. This is a derived context retrieved from Dataplex Dataset
  # Insights.
  # @!attribute [rw] left_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the first table.
  #     The size of this list must be the same as `right_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `right_schema_paths` list.
  # @!attribute [rw] right_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the second table.
  #     The size of this list must be the same as `left_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `left_schema_paths` list.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::Source>]
  #     Optional. Sources which generated the schema relation edge.
  # @!attribute [rw] confidence_score
  #   @return [::Float]
  #     Optional. A confidence score for the suggested relationship.
  #     Manually added edges have the highest confidence score.
  class SchemaRelationship
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents an ordered set of paths within the table schema.
    # @!attribute [rw] table_fqn
    #   @return [::String]
    #     The service-qualified full resource name of the table
    #     Ex:
    #     bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
    # @!attribute [rw] paths
    #   @return [::Array<::String>]
    #     The ordered list of paths within the table schema.
    class SchemaPaths
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Source which generated the schema relation edge.
    module Source
      # The source of the schema relationship is unspecified.
      SOURCE_UNSPECIFIED = 0

      # The source of the schema relationship is BigQuery job history.
      BIGQUERY_JOB_HISTORY = 1

      # The source of the schema relationship is LLM suggested.
      LLM_SUGGESTED = 2

      # The source of the schema relationship is BigQuery table constraints.
      BIGQUERY_TABLE_CONSTRAINTS = 3
    end
  end
end

#user_functions::Google::Cloud::GeminiDataAnalytics::V1::UserFunctions

Returns Optional. A collection of user functions to be included in context.

Returns:



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 61

class Context
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The relationship between two tables, including referencing and referenced
  # columns. This is a derived context retrieved from Dataplex Dataset
  # Insights.
  # @!attribute [rw] left_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the first table.
  #     The size of this list must be the same as `right_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `right_schema_paths` list.
  # @!attribute [rw] right_schema_paths
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::SchemaPaths]
  #     An ordered list of fields for the join from the second table.
  #     The size of this list must be the same as `left_schema_paths`.
  #     Each field at index i in this list must correspond to a field at the same
  #     index in the `left_schema_paths` list.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1::Context::SchemaRelationship::Source>]
  #     Optional. Sources which generated the schema relation edge.
  # @!attribute [rw] confidence_score
  #   @return [::Float]
  #     Optional. A confidence score for the suggested relationship.
  #     Manually added edges have the highest confidence score.
  class SchemaRelationship
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents an ordered set of paths within the table schema.
    # @!attribute [rw] table_fqn
    #   @return [::String]
    #     The service-qualified full resource name of the table
    #     Ex:
    #     bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
    # @!attribute [rw] paths
    #   @return [::Array<::String>]
    #     The ordered list of paths within the table schema.
    class SchemaPaths
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Source which generated the schema relation edge.
    module Source
      # The source of the schema relationship is unspecified.
      SOURCE_UNSPECIFIED = 0

      # The source of the schema relationship is BigQuery job history.
      BIGQUERY_JOB_HISTORY = 1

      # The source of the schema relationship is LLM suggested.
      LLM_SUGGESTED = 2

      # The source of the schema relationship is BigQuery table constraints.
      BIGQUERY_TABLE_CONSTRAINTS = 3
    end
  end
end