Class: Google::Cloud::GeminiDataAnalytics::V1::Conversation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb

Overview

Message for a conversation.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#agents::Array<::String>

Returns Required. Agent(s) in the conversation. Currently, only one agent is supported. This field is repeated to allow for future support of multiple agents in a conversation. Format: projects/{project}/locations/{location}/dataAgents/{agent}.

Returns:

  • (::Array<::String>)

    Required. Agent(s) in the conversation. Currently, only one agent is supported. This field is repeated to allow for future support of multiple agents in a conversation. Format: projects/{project}/locations/{location}/dataAgents/{agent}



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 67

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Creation timestamp.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 67

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kms_key::String

Returns Optional. Customer managed encryption key (CMEK) to use for encrypting the Conversation resources. Encryption will happen at Titan layer, we will pass the KMS key to Titan.

Format: projects/{project_id}/locations/{location}/keyRings/{key_ring_name}/cryptoKeys/{key_name}.

Returns:

  • (::String)

    Optional. Customer managed encryption key (CMEK) to use for encrypting the Conversation resources. Encryption will happen at Titan layer, we will pass the KMS key to Titan.

    Format: projects/{project_id}/locations/{location}/keyRings/{key_ring_name}/cryptoKeys/{key_name}.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 67

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Open-ended and user-defined labels that can be set by the client to tag a conversation (e.g. to filter conversations for specific surfaces/products).

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Open-ended and user-defined labels that can be set by the client to tag a conversation (e.g. to filter conversations for specific surfaces/products).



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 67

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#last_used_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp of the last used conversation.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 67

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#memory_paused::Boolean

Returns Optional. Whether memory is paused for this conversation.

Returns:

  • (::Boolean)

    Optional. Whether memory is paused for this conversation.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 67

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Optional. Identifier. The unique resource name of a conversation. Format: projects/{project}/locations/{location}/conversations/{conversation_id} {conversation_id} is the resource id and should be 63 characters or less and must match the format described in https://google.aip.dev/122#resource-id-segments

Example: projects/1234567890/locations/global/conversations/my-conversation.

It is recommended to skip setting this field during conversation creation as it will be inferred automatically and overwritten with the {parent}/conversations/{conversation_id}.

Returns:

  • (::String)

    Optional. Identifier. The unique resource name of a conversation. Format: projects/{project}/locations/{location}/conversations/{conversation_id} {conversation_id} is the resource id and should be 63 characters or less and must match the format described in https://google.aip.dev/122#resource-id-segments

    Example: projects/1234567890/locations/global/conversations/my-conversation.

    It is recommended to skip setting this field during conversation creation as it will be inferred automatically and overwritten with the {parent}/conversations/{conversation_id}.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 67

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end