Class: Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb

Overview

Client for the DataChatService service.

Service to ask a natural language question on top of BigQuery and Looker Studio datasources to get back streamed responses of various kinds to help provide a rich conversational answer.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#conversation_path, #crypto_key_path, #data_agent_path, #location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new DataChatService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the DataChatService client.

Yield Parameters:



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 132

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/geminidataanalytics/v1/data_chat_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @data_chat_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @data_chat_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @data_chat_service_stub.endpoint
    config.universe_domain = @data_chat_service_stub.universe_domain
    config.logger = @data_chat_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


196
197
198
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 196

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the DataChatService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all DataChatService clients
::Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 65

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "GeminiDataAnalytics", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 600.0
    default_config.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#chat(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::GeminiDataAnalytics::V1::Message> #chat(inline_context: nil, conversation_reference: nil, data_agent_context: nil, client_managed_resource_context: nil, looker_settings: nil, parent: nil, messages: nil, credentials: nil, thinking_mode: nil, model: nil) ⇒ ::Enumerable<::Google::Cloud::GeminiDataAnalytics::V1::Message>

Answers a data question by generating a stream of Message objects.

Examples:

Basic example

require "google/cloud/gemini_data_analytics/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::GeminiDataAnalytics::V1::ChatRequest.new

# Call the chat method to start streaming.
output = client.chat request

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::GeminiDataAnalytics::V1::Message
output.each do |current_response|
  p current_response
end

Overloads:

  • #chat(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::GeminiDataAnalytics::V1::Message>

    Pass arguments to chat via a request object, either of type ChatRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::GeminiDataAnalytics::V1::ChatRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #chat(inline_context: nil, conversation_reference: nil, data_agent_context: nil, client_managed_resource_context: nil, looker_settings: nil, parent: nil, messages: nil, credentials: nil, thinking_mode: nil, model: nil) ⇒ ::Enumerable<::Google::Cloud::GeminiDataAnalytics::V1::Message>

    Pass arguments to chat via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • inline_context (::Google::Cloud::GeminiDataAnalytics::V1::Context, ::Hash) (defaults to: nil)

      Optional. Inline context for the chat request. Use this to chat statelessly (without managed conversation persistence and without an Agent) by passing all context inline.

      Note: The following parameters are mutually exclusive: inline_context, conversation_reference, data_agent_context, client_managed_resource_context. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • conversation_reference (::Google::Cloud::GeminiDataAnalytics::V1::ConversationReference, ::Hash) (defaults to: nil)

      Optional. Reference to a persisted conversation and agent context. Use this to chat with an Agent using managed conversation persistence.

      Note: The following parameters are mutually exclusive: conversation_reference, inline_context, data_agent_context, client_managed_resource_context. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • data_agent_context (::Google::Cloud::GeminiDataAnalytics::V1::DataAgentContext, ::Hash) (defaults to: nil)

      Optional. Context for the chat request. Use this to chat with an Agent statelessly, without managed conversation persistence.

      Note: The following parameters are mutually exclusive: data_agent_context, inline_context, conversation_reference, client_managed_resource_context. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • client_managed_resource_context (::Google::Cloud::GeminiDataAnalytics::V1::ClientManagedResourceContext, ::Hash) (defaults to: nil)

      Optional. Context with client managed resources. Some clients may not use GDA managed resources including conversations and agents, instead they create and manage their own conversations and agents resources.

      Note: The following parameters are mutually exclusive: client_managed_resource_context, inline_context, conversation_reference, data_agent_context. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • looker_settings (::Google::Cloud::GeminiDataAnalytics::V1::LookerSettings, ::Hash) (defaults to: nil)

      Optional. Looker specific settings.

    • parent (::String) (defaults to: nil)

      Required. The parent value for chat request. Pattern: projects/{project}/locations/{location}

    • messages (::Array<::Google::Cloud::GeminiDataAnalytics::V1::Message, ::Hash>) (defaults to: nil)

      Required. Content of current conversation.

    • credentials (::Google::Cloud::GeminiDataAnalytics::V1::Credentials, ::Hash) (defaults to: nil)

      Optional. The credentials to use when calling the data source(s) specified in the context.

      This field can be used to provide credentials for various data sources. For example, when connecting to Looker, it currently supports both OAuth token and API key-based credentials, as described in Authentication with an SDK.

    • thinking_mode (::Google::Cloud::GeminiDataAnalytics::V1::ChatRequest::ThinkingMode) (defaults to: nil)

      Optional. The thinking mode to use for the agent loop. Defaults to THINKING_MODE_UNSPECIFIED if not specified.

    • model (::Google::Cloud::GeminiDataAnalytics::V1::ChatRequest::Model) (defaults to: nil)

      Optional. The model to use for the agent loop when processing the request. This setting only has an effect when context.options.model is not set.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 300

def chat request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::GeminiDataAnalytics::V1::ChatRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.chat..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::GeminiDataAnalytics::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.chat.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.chat.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_chat_service_stub.call_rpc :chat, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the DataChatService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



102
103
104
105
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 102

def configure
  yield @config if block_given?
  @config
end

#create_conversation(request, options = nil) ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Conversation #create_conversation(parent: nil, conversation_id: nil, conversation: nil, request_id: nil) ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Conversation

Creates a new conversation to persist the conversation history. Each conversation will have multiple messages associated with it.

Examples:

Basic example

require "google/cloud/gemini_data_analytics/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::GeminiDataAnalytics::V1::CreateConversationRequest.new

# Call the create_conversation method.
result = client.create_conversation request

# The returned object is of type Google::Cloud::GeminiDataAnalytics::V1::Conversation.
p result

Overloads:

  • #create_conversation(request, options = nil) ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Conversation

    Pass arguments to create_conversation via a request object, either of type CreateConversationRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::GeminiDataAnalytics::V1::CreateConversationRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_conversation(parent: nil, conversation_id: nil, conversation: nil, request_id: nil) ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Conversation

    Pass arguments to create_conversation via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent value for CreateConversationRequest. Format: projects/{project}/locations/{location}

    • conversation_id (::String) (defaults to: nil)

      Optional. The conversation id of the conversation to create. Must be unique within the parent. The allowed format is: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$. If not provided, the server will auto-generate a value for the id.

    • conversation (::Google::Cloud::GeminiDataAnalytics::V1::Conversation, ::Hash) (defaults to: nil)

      Required. The conversation to create.

    • request_id (::String) (defaults to: nil)

      Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 399

def create_conversation request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::GeminiDataAnalytics::V1::CreateConversationRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_conversation..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::GeminiDataAnalytics::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_conversation.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_conversation.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_chat_service_stub.call_rpc :create_conversation, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_conversation(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_conversation(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes a conversation.

Examples:

Basic example

require "google/cloud/gemini_data_analytics/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::GeminiDataAnalytics::V1::DeleteConversationRequest.new

# Call the delete_conversation method.
result = client.delete_conversation request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_conversation(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_conversation via a request object, either of type Google::Cloud::GeminiDataAnalytics::V1::DeleteConversationRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::GeminiDataAnalytics::V1::DeleteConversationRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_conversation(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_conversation via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Name of the resource. Format: projects/{project}/locations/{location}/conversations/{conversation}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 486

def delete_conversation request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::GeminiDataAnalytics::V1::DeleteConversationRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_conversation..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::GeminiDataAnalytics::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_conversation.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_conversation.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_chat_service_stub.call_rpc :delete_conversation, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_conversation(request, options = nil) ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Conversation #get_conversation(name: nil) ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Conversation

Gets details of a single conversation by using conversation id and parent.

Examples:

Basic example

require "google/cloud/gemini_data_analytics/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::GeminiDataAnalytics::V1::GetConversationRequest.new

# Call the get_conversation method.
result = client.get_conversation request

# The returned object is of type Google::Cloud::GeminiDataAnalytics::V1::Conversation.
p result

Overloads:

  • #get_conversation(request, options = nil) ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Conversation

    Pass arguments to get_conversation via a request object, either of type GetConversationRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::GeminiDataAnalytics::V1::GetConversationRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_conversation(name: nil) ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Conversation

    Pass arguments to get_conversation via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Name of the resource. Format: projects/{project}/locations/{location}/conversations/{conversation}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 573

def get_conversation request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::GeminiDataAnalytics::V1::GetConversationRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_conversation..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::GeminiDataAnalytics::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_conversation.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_conversation.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_chat_service_stub.call_rpc :get_conversation, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_conversations(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::GeminiDataAnalytics::V1::Conversation> #list_conversations(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::GeminiDataAnalytics::V1::Conversation>

Lists all conversations for a given parent.

Examples:

Basic example

require "google/cloud/gemini_data_analytics/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::GeminiDataAnalytics::V1::ListConversationsRequest.new

# Call the list_conversations method.
result = client.list_conversations request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::GeminiDataAnalytics::V1::Conversation.
  p item
end

Overloads:

  • #list_conversations(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::GeminiDataAnalytics::V1::Conversation>

    Pass arguments to list_conversations via a request object, either of type ListConversationsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::GeminiDataAnalytics::V1::ListConversationsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_conversations(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::GeminiDataAnalytics::V1::Conversation>

    Pass arguments to list_conversations via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent value for ListConversationsRequest. Format: projects/{project}/locations/{location}

    • page_size (::Integer) (defaults to: nil)

      Optional. Requested page size. Server may return fewer items than requested. The max page size is 100. All larger page sizes will be coerced to 100. If unspecified, server will pick 50 as an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token identifying a page of results the server should return.

    • filter (::String) (defaults to: nil)

      Optional. Returned conversations will match criteria specified within the filter. ListConversations allows filtering by:

      • agents
      • labels

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 675

def list_conversations request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::GeminiDataAnalytics::V1::ListConversationsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_conversations..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::GeminiDataAnalytics::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_conversations.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_conversations.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_chat_service_stub.call_rpc :list_conversations, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @data_chat_service_stub, :list_conversations, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_messages(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::GeminiDataAnalytics::V1::StorageMessage> #list_messages(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::GeminiDataAnalytics::V1::StorageMessage>

Lists all messages for a given conversation.

Examples:

Basic example

require "google/cloud/gemini_data_analytics/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::GeminiDataAnalytics::V1::DataChatService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::GeminiDataAnalytics::V1::ListMessagesRequest.new

# Call the list_messages method.
result = client.list_messages request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::GeminiDataAnalytics::V1::StorageMessage.
  p item
end

Overloads:

  • #list_messages(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::GeminiDataAnalytics::V1::StorageMessage>

    Pass arguments to list_messages via a request object, either of type ListMessagesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::GeminiDataAnalytics::V1::ListMessagesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_messages(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::GeminiDataAnalytics::V1::StorageMessage>

    Pass arguments to list_messages via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The conversation to list messages under. Format: projects/{project}/locations/{location}/conversations/{conversation_id}

    • page_size (::Integer) (defaults to: nil)

      Optional. Requested page size. Server may return fewer items than requested. The max page size is 100. All larger page sizes will be coerced to 100. If unspecified, server will pick 50 as an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token identifying a page of results the server should return.

    • filter (::String) (defaults to: nil)

      Optional. Filtering results. See AIP-160 for syntax.

      ListMessages allows filtering by:

      • create_time (e.g., createTime > "2025-01-28T06:51:56-08:00")
      • update_time

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 782

def list_messages request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::GeminiDataAnalytics::V1::ListMessagesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_messages..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::GeminiDataAnalytics::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_messages.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_messages.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_chat_service_stub.call_rpc :list_messages, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @data_chat_service_stub, :list_messages, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


203
204
205
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 203

def logger
  @data_chat_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


112
113
114
# File 'lib/google/cloud/gemini_data_analytics/v1/data_chat_service/client.rb', line 112

def universe_domain
  @data_chat_service_stub.universe_domain
end