Class: Google::Cloud::GeminiDataAnalytics::V1::DataMessage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb

Overview

A message produced during data retrieval.

Instance Attribute Summary collapse

Instance Attribute Details

#big_query_job::Google::Cloud::GeminiDataAnalytics::V1::BigQueryJob

Returns A BigQuery job executed by the system to retrieve data.

Note: The following fields are mutually exclusive: big_query_job, query, generated_sql, result, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::GeminiDataAnalytics::V1::BigQueryJob)

    A BigQuery job executed by the system to retrieve data.

    Note: The following fields are mutually exclusive: big_query_job, query, generated_sql, result, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 420

class DataMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#generated_sql::String

Returns SQL generated by the system to retrieve data.

Note: The following fields are mutually exclusive: generated_sql, query, result, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    SQL generated by the system to retrieve data.

    Note: The following fields are mutually exclusive: generated_sql, query, result, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 420

class DataMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#matched_query::Google::Cloud::GeminiDataAnalytics::V1::MatchedQuery

Returns A pre-existing query that was matched to retrieve data.

Note: The following fields are mutually exclusive: matched_query, query, generated_sql, result, big_query_job. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::GeminiDataAnalytics::V1::MatchedQuery)

    A pre-existing query that was matched to retrieve data.

    Note: The following fields are mutually exclusive: matched_query, query, generated_sql, result, big_query_job. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 420

class DataMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query::Google::Cloud::GeminiDataAnalytics::V1::DataQuery

Returns A data retrieval query.

Note: The following fields are mutually exclusive: query, generated_sql, result, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::GeminiDataAnalytics::V1::DataQuery)

    A data retrieval query.

    Note: The following fields are mutually exclusive: query, generated_sql, result, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 420

class DataMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#result::Google::Cloud::GeminiDataAnalytics::V1::DataResult

Returns Retrieved data.

Note: The following fields are mutually exclusive: result, query, generated_sql, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::GeminiDataAnalytics::V1::DataResult)

    Retrieved data.

    Note: The following fields are mutually exclusive: result, query, generated_sql, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 420

class DataMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end