Class: Google::Cloud::GeminiDataAnalytics::V1::DataResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb

Overview

Retrieved data.

Instance Attribute Summary collapse

Instance Attribute Details

#data::Array<::Google::Protobuf::Struct>

Returns Optional. The content of the data. Each row is a struct that matches the schema. Simple values are represented as strings, while nested structures are represented as lists or structs.

Returns:

  • (::Array<::Google::Protobuf::Struct>)

    Optional. The content of the data. Each row is a struct that matches the schema. Simple values are represented as strings, while nested structures are represented as lists or structs.



474
475
476
477
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 474

class DataResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#formatted_data::Array<::Google::Protobuf::Struct>

Returns Optional. Formatted representation of the data, when applicable. Each row is a struct that directly corresponds to the row at the same index within the data field. Its values are string representations of the original data, formatted according to data source specifications (e.g., "$1,234.56" for currency). Columns without formatting will default to their raw value representation. If no columns have formatting rules, this field will be empty.

Returns:

  • (::Array<::Google::Protobuf::Struct>)

    Optional. Formatted representation of the data, when applicable. Each row is a struct that directly corresponds to the row at the same index within the data field. Its values are string representations of the original data, formatted according to data source specifications (e.g., "$1,234.56" for currency). Columns without formatting will default to their raw value representation. If no columns have formatting rules, this field will be empty.



474
475
476
477
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 474

class DataResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Optional. A snake-case name for the data result that reflects its contents. The name is used to pass the result around by reference, and serves as a signal about its meaning.

  • Example: "total_sales_by_product"
  • Example: "sales_for_product_12345".

Returns:

  • (::String)

    Optional. A snake-case name for the data result that reflects its contents. The name is used to pass the result around by reference, and serves as a signal about its meaning.

    • Example: "total_sales_by_product"
    • Example: "sales_for_product_12345"


474
475
476
477
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 474

class DataResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema::Google::Cloud::GeminiDataAnalytics::V1::Schema

Returns Optional. The schema of the data.

Returns:



474
475
476
477
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 474

class DataResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end