Class: Google::Cloud::GeminiDataAnalytics::V1::Datasource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb

Overview

A datasource that can be used to answer questions.

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_property_graph_reference::Google::Cloud::GeminiDataAnalytics::V1::BigQueryPropertyGraphReference

Returns A reference to a BigQuery property graph.

Note: The following fields are mutually exclusive: bigquery_property_graph_reference, bigquery_table_reference, studio_datasource_id, looker_explore_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::GeminiDataAnalytics::V1::BigQueryPropertyGraphReference)

    A reference to a BigQuery property graph.

    Note: The following fields are mutually exclusive: bigquery_property_graph_reference, bigquery_table_reference, studio_datasource_id, looker_explore_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.



192
193
194
195
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 192

class Datasource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#bigquery_table_reference::Google::Cloud::GeminiDataAnalytics::V1::BigQueryTableReference

Returns A reference to a BigQuery table.

Note: The following fields are mutually exclusive: bigquery_table_reference, studio_datasource_id, looker_explore_reference, bigquery_property_graph_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::GeminiDataAnalytics::V1::BigQueryTableReference)

    A reference to a BigQuery table.

    Note: The following fields are mutually exclusive: bigquery_table_reference, studio_datasource_id, looker_explore_reference, bigquery_property_graph_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.



192
193
194
195
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 192

class Datasource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#looker_explore_reference::Google::Cloud::GeminiDataAnalytics::V1::LookerExploreReference

Returns A reference to a Looker explore.

Note: The following fields are mutually exclusive: looker_explore_reference, bigquery_table_reference, studio_datasource_id, bigquery_property_graph_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::GeminiDataAnalytics::V1::LookerExploreReference)

    A reference to a Looker explore.

    Note: The following fields are mutually exclusive: looker_explore_reference, bigquery_table_reference, studio_datasource_id, bigquery_property_graph_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.



192
193
194
195
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 192

class Datasource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema::Google::Cloud::GeminiDataAnalytics::V1::Schema

Returns Optional. The schema of the datasource.

Returns:



192
193
194
195
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 192

class Datasource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#struct_schema::Google::Protobuf::Struct

Returns Optional. A struct representation of the schema. This is populated for datasources with schemas that cannot be fully represented by the strongly-typed schema field.

For Looker datasources, this maps to the LookmlModelExplore type: https://cloud.google.com/looker/docs/reference/looker-api/latest/types/LookmlModelExplore.

Returns:



192
193
194
195
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 192

class Datasource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#studio_datasource_id::String

Returns A reference to a Looker Studio datasource.

Note: The following fields are mutually exclusive: studio_datasource_id, bigquery_table_reference, looker_explore_reference, bigquery_property_graph_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    A reference to a Looker Studio datasource.

    Note: The following fields are mutually exclusive: studio_datasource_id, bigquery_table_reference, looker_explore_reference, bigquery_property_graph_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.



192
193
194
195
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 192

class Datasource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end