Class: Google::Cloud::GeminiDataAnalytics::V1::ListMessagesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::ListMessagesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb
Overview
Request for listing chat messages based on parent and conversation_id.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filtering results. See AIP-160 for syntax.
ListMessages allows filtering by:
- create_time (e.g.,
createTime > "2025-01-28T06:51:56-08:00") - update_time.
47 48 49 50 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 47 class ListMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than
requested. The max page size is 100. All larger page sizes will be
coerced to 100. If unspecified, server will pick 50 as an appropriate
default.
47 48 49 50 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 47 class ListMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
47 48 49 50 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 47 class ListMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The conversation to list messages under.
Format:
projects/{project}/locations/{location}/conversations/{conversation_id}.
47 48 49 50 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 47 class ListMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |