Class: Google::Cloud::GeminiDataAnalytics::V1::LookerQuery

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/context.rb

Overview

Looker Query Object Looker API documentation.

Defined Under Namespace

Classes: Filter

Instance Attribute Summary collapse

Instance Attribute Details

#client_id::String

Returns Optional. The short alphanumeric identifier for the query, used for share links and Explore URLs (e.g., in the qid parameter). Maps to client_id in the Looker API Query resource.

Returns:

  • (::String)

    Optional. The short alphanumeric identifier for the query, used for share links and Explore URLs (e.g., in the qid parameter). Maps to client_id in the Looker API Query resource.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 276

class LookerQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Looker query filter.
  # @!attribute [rw] field
  #   @return [::String]
  #     Required. The field to filter on.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value for the field to filter on.
  #     Optional so we can preserve the default value as an empty
  #     string, important to get a valid and working Looker Explore url.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#explore::String

Returns Required. The LookML explore used to generate the query.

Returns:

  • (::String)

    Required. The LookML explore used to generate the query.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 276

class LookerQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Looker query filter.
  # @!attribute [rw] field
  #   @return [::String]
  #     Required. The field to filter on.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value for the field to filter on.
  #     Optional so we can preserve the default value as an empty
  #     string, important to get a valid and working Looker Explore url.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#fields::Array<::String>

Returns Optional. The fields to retrieve from the explore.

Returns:

  • (::Array<::String>)

    Optional. The fields to retrieve from the explore.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 276

class LookerQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Looker query filter.
  # @!attribute [rw] field
  #   @return [::String]
  #     Required. The field to filter on.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value for the field to filter on.
  #     Optional so we can preserve the default value as an empty
  #     string, important to get a valid and working Looker Explore url.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#filters::Array<::Google::Cloud::GeminiDataAnalytics::V1::LookerQuery::Filter>

Returns Optional. The filters to apply to the explore.

Returns:



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 276

class LookerQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Looker query filter.
  # @!attribute [rw] field
  #   @return [::String]
  #     Required. The field to filter on.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value for the field to filter on.
  #     Optional so we can preserve the default value as an empty
  #     string, important to get a valid and working Looker Explore url.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#limit::String

Returns Optional. Limit in the query.

Returns:

  • (::String)

    Optional. Limit in the query.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 276

class LookerQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Looker query filter.
  # @!attribute [rw] field
  #   @return [::String]
  #     Required. The field to filter on.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value for the field to filter on.
  #     Optional so we can preserve the default value as an empty
  #     string, important to get a valid and working Looker Explore url.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#model::String

Returns Required. The LookML model used to generate the query.

Returns:

  • (::String)

    Required. The LookML model used to generate the query.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 276

class LookerQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Looker query filter.
  # @!attribute [rw] field
  #   @return [::String]
  #     Required. The field to filter on.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value for the field to filter on.
  #     Optional so we can preserve the default value as an empty
  #     string, important to get a valid and working Looker Explore url.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#query_id::String

Returns Optional. The primary identifier for the query resource in Looker, used for API operations. Maps to id (or slug) in the Looker API Query resource.

Returns:

  • (::String)

    Optional. The primary identifier for the query resource in Looker, used for API operations. Maps to id (or slug) in the Looker API Query resource.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 276

class LookerQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Looker query filter.
  # @!attribute [rw] field
  #   @return [::String]
  #     Required. The field to filter on.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value for the field to filter on.
  #     Optional so we can preserve the default value as an empty
  #     string, important to get a valid and working Looker Explore url.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#sorts::Array<::String>

Returns Optional. The sorts to apply to the explore.

Returns:

  • (::Array<::String>)

    Optional. The sorts to apply to the explore.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 276

class LookerQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Looker query filter.
  # @!attribute [rw] field
  #   @return [::String]
  #     Required. The field to filter on.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value for the field to filter on.
  #     Optional so we can preserve the default value as an empty
  #     string, important to get a valid and working Looker Explore url.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end