Class: Google::Cloud::GeminiDataAnalytics::V1::LookerSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb

Overview

Message to hold Looker specific custom settings.

Instance Attribute Summary collapse

Instance Attribute Details

#enable_dev_mode::Boolean

Returns Optional. Whether to operate in Looker's Development Mode. If true, the API session will be switched to the "dev" workspace, allowing interaction with LookML changes in the user's development branch. If false or unset, the session remains in the default state (Production Mode). See https://cloud.google.com/looker/docs/dev-mode-prod-mode.

Returns:

  • (::Boolean)

    Optional. Whether to operate in Looker's Development Mode. If true, the API session will be switched to the "dev" workspace, allowing interaction with LookML changes in the user's development branch. If false or unset, the session remains in the default state (Production Mode). See https://cloud.google.com/looker/docs/dev-mode-prod-mode.



256
257
258
259
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 256

class LookerSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end