Class: Google::Cloud::GeminiDataAnalytics::V1::MatchedQuery

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/context.rb

Overview

A matched query message represents the agent having matched one of the example queries supplied in context as being applicable to the current question. It will also contain additional info during the matching process.

Instance Attribute Summary collapse

Instance Attribute Details

#example_query::Google::Cloud::GeminiDataAnalytics::V1::ExampleQuery

Returns The query that was matched based on an example query.

Returns:



212
213
214
215
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 212

class MatchedQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query_parameter_values::Array<::Google::Cloud::GeminiDataAnalytics::V1::QueryParameterValues>

Returns The extracted values for the query parameters.

Returns:



212
213
214
215
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 212

class MatchedQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end