Class: Google::Cloud::GeminiDataAnalytics::V1::Schema

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb

Overview

The schema of a Datasource or QueryResult instance.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. A textual description of the table's content and purpose. For example: "Contains information about customer orders in our e-commerce store." Currently only used for BigQuery data sources.

Returns:

  • (::String)

    Optional. A textual description of the table's content and purpose. For example: "Contains information about customer orders in our e-commerce store." Currently only used for BigQuery data sources.



225
226
227
228
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 225

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Optional. Table display_name (same as label in cloud/data_analytics/anarres/data/looker/proto/model_explore.proto), not required, currently only Looker has this field.

Returns:

  • (::String)

    Optional. Table display_name (same as label in cloud/data_analytics/anarres/data/looker/proto/model_explore.proto), not required, currently only Looker has this field.



225
226
227
228
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 225

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#fields::Array<::Google::Cloud::GeminiDataAnalytics::V1::Field>

Returns Optional. The fields in the schema.

Returns:



225
226
227
228
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 225

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#filters::Array<::Google::Cloud::GeminiDataAnalytics::V1::DataFilter>

Returns Optional. The filters on the datasource's underlying data. Currently only used for Looker data sources.

Returns:



225
226
227
228
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 225

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#synonyms::Array<::String>

Returns Optional. A list of alternative names or synonyms that can be used to refer to the table. For example: ["sales", "orders", "purchases"]. Currently only used for BigQuery data sources.

Returns:

  • (::Array<::String>)

    Optional. A list of alternative names or synonyms that can be used to refer to the table. For example: ["sales", "orders", "purchases"]. Currently only used for BigQuery data sources.



225
226
227
228
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 225

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tags::Array<::String>

Returns Optional. A list of tags or keywords associated with the table, used for categorization. For example: ["transaction", "revenue", "customer_data"]. Currently only used for BigQuery data sources.

Returns:

  • (::Array<::String>)

    Optional. A list of tags or keywords associated with the table, used for categorization. For example: ["transaction", "revenue", "customer_data"]. Currently only used for BigQuery data sources.



225
226
227
228
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 225

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end