Class: Google::Cloud::GeminiDataAnalytics::V1::UserMessage
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::UserMessage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb
Overview
A message from the user that is interacting with the system.
Instance Attribute Summary collapse
-
#text ⇒ ::String
Text should use this field instead of blob.
Instance Attribute Details
#text ⇒ ::String
Returns Text should use this field instead of blob.
265 266 267 268 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 265 class UserMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |