Class: Google::Cloud::GeminiDataAnalytics::V1::ChatRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::ChatRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb
Overview
Request for Chat.
Defined Under Namespace
Modules: Model, ThinkingMode
Instance Attribute Summary collapse
-
#client_managed_resource_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ClientManagedResourceContext
Optional.
-
#conversation_reference ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ConversationReference
Optional.
-
#credentials ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Credentials
Optional.
-
#data_agent_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::DataAgentContext
Optional.
-
#inline_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Context
Optional.
-
#looker_settings ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::LookerSettings
Optional.
-
#messages ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1::Message>
Required.
-
#model ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ChatRequest::Model
Optional.
-
#parent ⇒ ::String
Required.
-
#thinking_mode ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ChatRequest::ThinkingMode
Optional.
Instance Attribute Details
#client_managed_resource_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ClientManagedResourceContext
Returns Optional. Context with client managed resources. Some clients may not use GDA managed resources including conversations and agents, instead they create and manage their own conversations and agents resources.
Note: The following fields are mutually exclusive: client_managed_resource_context, inline_context, conversation_reference, data_agent_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#conversation_reference ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ConversationReference
Returns Optional. Reference to a persisted conversation and agent context. Use this to chat with an Agent using managed conversation persistence.
Note: The following fields are mutually exclusive: conversation_reference, inline_context, data_agent_context, client_managed_resource_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#credentials ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Credentials
Returns Optional. The credentials to use when calling the data source(s) specified in the context.
This field can be used to provide credentials for various data sources. For example, when connecting to Looker, it currently supports both OAuth token and API key-based credentials, as described in Authentication with an SDK.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#data_agent_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::DataAgentContext
Returns Optional. Context for the chat request. Use this to chat with an Agent statelessly, without managed conversation persistence.
Note: The following fields are mutually exclusive: data_agent_context, inline_context, conversation_reference, client_managed_resource_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#inline_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Context
Returns Optional. Inline context for the chat request. Use this to chat statelessly (without managed conversation persistence and without an Agent) by passing all context inline.
Note: The following fields are mutually exclusive: inline_context, conversation_reference, data_agent_context, client_managed_resource_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#looker_settings ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::LookerSettings
Returns Optional. Looker specific settings.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#messages ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1::Message>
Returns Required. Content of current conversation.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#model ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ChatRequest::Model
Returns Optional. The model to use for the agent loop when processing the request. This setting only has an effect when context.options.model is not set.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#parent ⇒ ::String
Returns Required. The parent value for chat request.
Pattern: projects/{project}/locations/{location}.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#thinking_mode ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ChatRequest::ThinkingMode
Returns Optional. The thinking mode to use for the agent loop. Defaults to THINKING_MODE_UNSPECIFIED if not specified.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 132 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |