Class: Google::Cloud::GeminiDataAnalytics::V1::CitationAnchor::TextMessageCitationAnchor
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::CitationAnchor::TextMessageCitationAnchor
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/context.rb
Overview
Citation anchor within a TextMessage.
Instance Attribute Summary collapse
-
#end_offset_bytes ⇒ ::Integer
readonly
Output only.
-
#part_index ⇒ ::Integer
readonly
Output only.
-
#source_ids ⇒ ::Array<::String>
readonly
Output only.
-
#start_offset_bytes ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#end_offset_bytes ⇒ ::Integer (readonly)
Returns Output only. The offset, measured in UTF-8 bytes, within the part string where the citation ends (exclusive). Example: For the text "Hello, world" where "world" is cited, the start offset bytes (inclusive) is 7 and the end offset bytes (exclusive) is 12.
442 443 444 445 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 442 class TextMessageCitationAnchor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#part_index ⇒ ::Integer (readonly)
Returns Output only. The 0-based index of the part within the TextMessage.parts field.
442 443 444 445 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 442 class TextMessageCitationAnchor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_ids ⇒ ::Array<::String> (readonly)
Returns Output only. The ids of the sources that are cited.
442 443 444 445 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 442 class TextMessageCitationAnchor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_offset_bytes ⇒ ::Integer (readonly)
Returns Output only. The offset, measured in UTF-8 bytes, within the part string where the citation begins (inclusive). Example: For the text "Hello, world" where "world" is cited, the start offset bytes (inclusive) is 7 and the end offset bytes (exclusive) is 12.
442 443 444 445 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 442 class TextMessageCitationAnchor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |