Class: Google::Cloud::GeminiDataAnalytics::V1::CitationSource
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::CitationSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/context.rb
Overview
The source of the citation.
Instance Attribute Summary collapse
-
#example_query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ExampleQuery
readonly
Output only.
-
#glossary_term ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::GlossaryTerm
readonly
Output only.
-
#id ⇒ ::String
readonly
Output only.
-
#title ⇒ ::String
readonly
Output only.
-
#uri ⇒ ::String
readonly
Output only.
Instance Attribute Details
#example_query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ExampleQuery (readonly)
Returns Output only. The example query used as the source.
Note: The following fields are mutually exclusive: example_query, uri, glossary_term. If a field in that set is populated, all other fields in the set will automatically be cleared.
409 410 411 412 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 409 class CitationSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#glossary_term ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::GlossaryTerm (readonly)
Returns Output only. The glossary term used as the source.
Note: The following fields are mutually exclusive: glossary_term, uri, example_query. If a field in that set is populated, all other fields in the set will automatically be cleared.
409 410 411 412 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 409 class CitationSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String (readonly)
Returns Output only. Unique identifier of the source. This ID is service-generated
and is unique within the scope of a single Citation message.
409 410 411 412 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 409 class CitationSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#title ⇒ ::String (readonly)
Returns Output only. The title of the source.
409 410 411 412 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 409 class CitationSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uri ⇒ ::String (readonly)
Returns Output only. The uri used as the source, such as a web grounding URL.
Note: The following fields are mutually exclusive: uri, example_query, glossary_term. If a field in that set is populated, all other fields in the set will automatically be cleared.
409 410 411 412 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 409 class CitationSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |