Class: Google::Cloud::GeminiDataAnalytics::V1::ConversationOptions
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::ConversationOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/context.rb
Overview
Options for the conversation.
Defined Under Namespace
Modules: Model
Instance Attribute Summary collapse
-
#analysis ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::AnalysisOptions
Optional.
-
#datasource ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::DatasourceOptions
Optional.
-
#model ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ConversationOptions::Model
Optional.
Instance Attribute Details
#analysis ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::AnalysisOptions
Returns Optional. Options for analysis.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 324 class ConversationOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Allowed models for the agent/conversation. module Model # No model specified. The model may be set on the chat request, or the # default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#datasource ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::DatasourceOptions
Returns Optional. Options for datasources.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 324 class ConversationOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Allowed models for the agent/conversation. module Model # No model specified. The model may be set on the chat request, or the # default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |
#model ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::ConversationOptions::Model
Returns Optional. The model to use for the agent loop.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 324 class ConversationOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Allowed models for the agent/conversation. module Model # No model specified. The model may be set on the chat request, or the # default model will be used. Currently, this is # `gemini-3.0-flash-preview`. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. Currently, this is # `gemini-2.5-flash`. This constrains the request level settings. The # default will change to `gemini-2.5-flash`, and setting `thinking_mode` # will not be supported. LATEST_GA_MODEL = 1 end end |