Class: Google::Cloud::GeminiDataAnalytics::V1::DataAgent
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::DataAgent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb
Overview
Message describing a DataAgent object.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#data_analytics_agent ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::DataAnalyticsAgent
Data analytics agent.
-
#delete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Optional.
-
#kms_key ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Optional.
-
#purge_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the data agent was created.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#data_analytics_agent ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::DataAnalyticsAgent
Returns Data analytics agent.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#delete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] The time the data agent was soft deleted.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. Description of the agent.
- Must be between 1-1024 characters.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Optional. User friendly display name.
- Must be between 1-256 characters.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kms_key ⇒ ::String
Returns Optional. Customer managed encryption key (CMEK) to use for encrypting the
DataAgent resources. Cloud KMS CryptoKeys must reside in the same location
as the DataAgent. The expected format is
projects/*/locations/*/keyRings/*/cryptoKeys/*.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels to help users filter related agents. For example, "sales", "business", "etl", and so on. Note labels are used only for filtering and not for policies. See the labels documentation for more details on label usage.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Optional. Identifier. The unique resource name of a DataAgent.
Format:
projects/{project}/locations/{location}/dataAgents/{data_agent_id}
{data_agent} is the resource id and should be 63 characters or less and
must match the format described in
https://google.aip.dev/122#resource-id-segments
Example: projects/1234567890/locations/global/dataAgents/my-agent.
It is recommended to skip setting this field during agent creation as it will be inferred automatically and overwritten with the {parent}/dataAgents/{data_agent_id}.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#purge_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp in UTC of when this data agent is considered expired. This is always provided on output, regardless of what was sent on input.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the data agent was last updated.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_agent.rb', line 80 class DataAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |