Class: Google::Cloud::GeminiDataAnalytics::V1::DataAgentContext
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::DataAgentContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb
Overview
Context for the chat request using a data agent.
Defined Under Namespace
Modules: ContextVersion
Instance Attribute Summary collapse
-
#context_version ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::DataAgentContext::ContextVersion
Optional.
-
#data_agent ⇒ ::String
Required.
Instance Attribute Details
#context_version ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::DataAgentContext::ContextVersion
Returns Optional. Version of context to be used by DCS (e.g. STAGING, PUBLISHED).
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 169 class DataAgentContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of context versions supported by DCS. # There are two versions of context. This is to maintain versioning for the # data agent. module ContextVersion # Unspecified or unrecognized. CONTEXT_VERSION_UNSPECIFIED = 0 # Using this version, DCS will use the latest staging context for the # data agent. STAGING = 1 # Using this version, DCS will use the latest published context for the # data agent. PUBLISHED = 2 end end |
#data_agent ⇒ ::String
Returns Required. The name of the data agent resource.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 169 class DataAgentContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of context versions supported by DCS. # There are two versions of context. This is to maintain versioning for the # data agent. module ContextVersion # Unspecified or unrecognized. CONTEXT_VERSION_UNSPECIFIED = 0 # Using this version, DCS will use the latest staging context for the # data agent. STAGING = 1 # Using this version, DCS will use the latest published context for the # data agent. PUBLISHED = 2 end end |