Class: Google::Cloud::GeminiDataAnalytics::V1::DatasourceReferences
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::DatasourceReferences
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb
Overview
A collection of references to datasources.
Instance Attribute Summary collapse
-
#bq ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::BigQueryTableReferences
References to BigQuery tables.
-
#looker ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::LookerExploreReferences
References to Looker Explores.
-
#studio ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::StudioDatasourceReferences
References to Looker Studio datasources.
Instance Attribute Details
#bq ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::BigQueryTableReferences
Returns References to BigQuery tables.
Note: The following fields are mutually exclusive: bq, studio, looker. If a field in that set is populated, all other fields in the set will automatically be cleared.
40 41 42 43 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 40 class DatasourceReferences include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#looker ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::LookerExploreReferences
Returns References to Looker Explores.
Note: The following fields are mutually exclusive: looker, bq, studio. If a field in that set is populated, all other fields in the set will automatically be cleared.
40 41 42 43 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 40 class DatasourceReferences include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#studio ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::StudioDatasourceReferences
Returns References to Looker Studio datasources.
Note: The following fields are mutually exclusive: studio, bq, looker. If a field in that set is populated, all other fields in the set will automatically be cleared.
40 41 42 43 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 40 class DatasourceReferences include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |