Class: Google::Cloud::GeminiDataAnalytics::V1::Field
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::Field
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb
Overview
A field in a schema.
Instance Attribute Summary collapse
-
#category ⇒ ::String
Optional.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Optional.
-
#mode ⇒ ::String
Optional.
-
#name ⇒ ::String
Optional.
-
#subfields ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1::Field>
Optional.
-
#synonyms ⇒ ::Array<::String>
Optional.
-
#tags ⇒ ::Array<::String>
Optional.
-
#type ⇒ ::String
Optional.
-
#value_format ⇒ ::String
Optional.
Instance Attribute Details
#category ⇒ ::String
Returns Optional. Field category, not required, currently only useful for Looker.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. A brief description of the field.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Optional. Field display_name (same as label in.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mode ⇒ ::String
Returns Optional. The mode of the field (e.g., NULLABLE, REPEATED).
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Optional. The name of the field.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subfields ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1::Field>
Returns Optional. Recursive property for nested schema structures.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#synonyms ⇒ ::Array<::String>
Returns Optional. A list of alternative names or synonyms that can be used to refer to this field. For example: ["id", "customerid", "cust_id"]. Currently only used for BigQuery data sources.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tags ⇒ ::Array<::String>
Returns Optional. A list of tags or keywords associated with the field, used for categorization. For example: ["identifier", "customer", "pii"]. Currently only used for BigQuery data sources.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::String
Returns Optional. The type of the field.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#value_format ⇒ ::String
Returns Optional. Looker only. Value format of the field. Ref: https://cloud.google.com/looker/docs/reference/param-field-value-format.
267 268 269 270 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 267 class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |