Class: Google::Cloud::GeminiDataAnalytics::V1::GlossaryTerm
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::GlossaryTerm
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/context.rb
Overview
Definition of a term within a specific domain.
Instance Attribute Summary collapse
-
#description ⇒ ::String
Required.
-
#display_name ⇒ ::String
Required.
-
#labels ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#description ⇒ ::String
Returns Required. The description or meaning of the term. For example: "Click-through rate", "The percentage of users who complete a desired action", "An order that is waiting to be processed.".
309 310 311 312 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 309 class GlossaryTerm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. User friendly display name of the glossary term being defined. For example: "CTR", "conversion rate", "pending".
309 310 311 312 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 309 class GlossaryTerm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#labels ⇒ ::Array<::String>
Returns Optional. A list of general purpose labels associated to this term. For example: ["click rate", "clickthrough", "waiting"].
309 310 311 312 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 309 class GlossaryTerm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |