Class: Google::Cloud::GeminiDataAnalytics::V1::ListConversationsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::ListConversationsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb
Overview
Request for listing conversations based on parent.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Returned conversations will match criteria specified within the filter. ListConversations allows filtering by:
- agents
- labels.
137 138 139 140 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 137 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than
requested. The max page size is 100. All larger page sizes will be
coerced to 100. If unspecified, server will pick 50 as an appropriate
default.
137 138 139 140 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 137 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
137 138 139 140 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 137 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent value for ListConversationsRequest.
Format: projects/{project}/locations/{location}.
137 138 139 140 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 137 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |