Class: Google::Cloud::GeminiDataAnalytics::V1::ListConversationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::ListConversationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb
Overview
Message for response to listing conversations.
Instance Attribute Summary collapse
-
#conversations ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1::Conversation>
The list of conversations.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
Instance Attribute Details
#conversations ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1::Conversation>
Returns The list of conversations.
149 150 151 152 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 149 class ListConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
149 150 151 152 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/conversation.rb', line 149 class ListConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |