Class: Google::Cloud::GeminiDataAnalytics::V1::LookerExploreReference
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::LookerExploreReference
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb
Overview
Message representing a reference to a single Looker explore.
Instance Attribute Summary collapse
-
#explore ⇒ ::String
Required.
-
#looker_instance_uri ⇒ ::String
Required.
-
#lookml_model ⇒ ::String
Required.
-
#private_looker_instance_info ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::PrivateLookerInstanceInfo
Private Looker instance info.
-
#schema ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Schema
Optional.
Instance Attribute Details
#explore ⇒ ::String
Returns Required. Looker Explore, as outlined in Major LookML structures. Name of the LookML Explore.
127 128 129 130 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 127 class LookerExploreReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#looker_instance_uri ⇒ ::String
Returns Required. The base url of the Looker instance.
Note: The following fields are mutually exclusive: looker_instance_uri, private_looker_instance_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
127 128 129 130 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 127 class LookerExploreReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#lookml_model ⇒ ::String
Returns Required. Looker model, as outlined in Major LookML structures. Name of the LookML model.
127 128 129 130 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 127 class LookerExploreReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#private_looker_instance_info ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::PrivateLookerInstanceInfo
Returns Private Looker instance info.
Note: The following fields are mutually exclusive: private_looker_instance_info, looker_instance_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.
127 128 129 130 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 127 class LookerExploreReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#schema ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::Schema
Returns Optional. The schema of the datasource.
127 128 129 130 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/datasource.rb', line 127 class LookerExploreReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |