Class: Google::Cloud::GeminiDataAnalytics::V1::LookerGoldenQuery
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::LookerGoldenQuery
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/context.rb
Overview
A golden query for Looker, including natural language questions and a corresponding Looker Query. Analogous to ExampleQuery.
Instance Attribute Summary collapse
-
#looker_query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::LookerQuery
Optional.
-
#natural_language_questions ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#looker_query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::LookerQuery
Returns Optional. The Looker Query corresponding to the natural language questions.
240 241 242 243 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 240 class LookerGoldenQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#natural_language_questions ⇒ ::Array<::String>
Returns Optional. Natural language questions that a user might ask. For example: "How many orders were placed last month?".
240 241 242 243 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 240 class LookerGoldenQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |