Class: Google::Cloud::GeminiDataAnalytics::V1::Message
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::Message
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb
Overview
A message from an interaction between the user and the system.
Instance Attribute Summary collapse
-
#message_id ⇒ ::String
Optional.
-
#system_message ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::SystemMessage
A message from the system in response to the user.
-
#timestamp ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#user_message ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::UserMessage
A message from the user that is interacting with the system.
Instance Attribute Details
#message_id ⇒ ::String
Returns Optional. unique id of the message in the conversation for persistence.
242 243 244 245 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 242 class Message include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#system_message ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::SystemMessage
Returns A message from the system in response to the user.
Note: The following fields are mutually exclusive: system_message, user_message. If a field in that set is populated, all other fields in the set will automatically be cleared.
242 243 244 245 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 242 class Message include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#timestamp ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. For user messages, this is the time at which the system received the message. For system messages, this is the time at which the system generated the message.
242 243 244 245 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 242 class Message include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_message ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::UserMessage
Returns A message from the user that is interacting with the system.
Note: The following fields are mutually exclusive: user_message, system_message. If a field in that set is populated, all other fields in the set will automatically be cleared.
242 243 244 245 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 242 class Message include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |