Class: Google::Cloud::GeminiDataAnalytics::V1::QueryParameter
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::QueryParameter
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/context.rb
Overview
A query parameter message represents a parameter that can be used to parameterize a SQL query.
Instance Attribute Summary collapse
-
#data_type ⇒ ::String
Required.
-
#description ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#data_type ⇒ ::String
Returns Required. The data type of the parameter, e.g. "STRING", "INT64", "DATE", etc. For valid values, see the BigQuery documentation. This will be used to populate google.cloud.bigquery.v2.QueryParameterType.type.
198 199 200 201 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 198 class QueryParameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. The description of the parameter that can be used by LLM to extract the parameter value from the user question.
198 199 200 201 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 198 class QueryParameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the parameter reference in the SQL query.
198 199 200 201 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/context.rb', line 198 class QueryParameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |