Class: Google::Cloud::GeminiDataAnalytics::V1::TextMessage
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1::TextMessage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb
Overview
A multi-part text message.
Defined Under Namespace
Modules: TextType
Instance Attribute Summary collapse
-
#parts ⇒ ::Array<::String>
Optional.
-
#text_type ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::TextMessage::TextType
Optional.
-
#thought_signature ⇒ ::String
Optional.
Instance Attribute Details
#parts ⇒ ::Array<::String>
Returns Optional. The parts of the message.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 332 class TextMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the text message. module TextType # The default text type. TEXT_TYPE_UNSPECIFIED = 0 # The text is a final response to the user question. FINAL_RESPONSE = 1 # The text is a thought from the model. THOUGHT = 2 # The text is an informational message about the agent's progress, such as # a tool being invoked. This is distinct from the agent's internal thought # process (`THOUGHT`) and the final answer to the user # (`FINAL_RESPONSE`). These messages provide insight into the agent's # actions. PROGRESS = 3 # The text is a list of follow-up questions suggested. # Each item in parts is a follow-up question. FOLLOWUP_QUESTIONS = 4 end end |
#text_type ⇒ ::Google::Cloud::GeminiDataAnalytics::V1::TextMessage::TextType
Returns Optional. The type of the text message.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 332 class TextMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the text message. module TextType # The default text type. TEXT_TYPE_UNSPECIFIED = 0 # The text is a final response to the user question. FINAL_RESPONSE = 1 # The text is a thought from the model. THOUGHT = 2 # The text is an informational message about the agent's progress, such as # a tool being invoked. This is distinct from the agent's internal thought # process (`THOUGHT`) and the final answer to the user # (`FINAL_RESPONSE`). These messages provide insight into the agent's # actions. PROGRESS = 3 # The text is a list of follow-up questions suggested. # Each item in parts is a follow-up question. FOLLOWUP_QUESTIONS = 4 end end |
#thought_signature ⇒ ::String
Returns Optional. An opaque signature for a thought so it can be reused in subsequent requests.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1/data_chat_service.rb', line 332 class TextMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the text message. module TextType # The default text type. TEXT_TYPE_UNSPECIFIED = 0 # The text is a final response to the user question. FINAL_RESPONSE = 1 # The text is a thought from the model. THOUGHT = 2 # The text is an informational message about the agent's progress, such as # a tool being invoked. This is distinct from the agent's internal thought # process (`THOUGHT`) and the final answer to the user # (`FINAL_RESPONSE`). These messages provide insight into the agent's # actions. PROGRESS = 3 # The text is a list of follow-up questions suggested. # Each item in parts is a follow-up question. FOLLOWUP_QUESTIONS = 4 end end |